Funding
=======
The following institutions, missions, and programs have provided funding
for pysatCDAAC development.

Institutions
------------
 - The Catholic University of America (CUA)
 - Cosmic Studio
 - Defense Advanced Research Projects Agency (DARPA) Defense Sciences Office
 - National Aeronautics and Space Administration (NASA)
 - National Oceanic and Atmospheric Administration (NOAA)
 - National Science Foundation (NSF)
 - Office of Naval Research (ONR)

Missions
--------
 - NOAA Constellation Observing System for Meteorology Ionosphere and Climate
   (COSMIC-2)

Programs
--------
 - NSF 125908, AGS-1651393
 - NASA Space Precipitation Impacts (SPI) project at Goddard Space Flight Center
   through the Heliophysics Internal Science Funding Model.
 - Naval Research Laboratory N00173191G016 and N0017322P0744
 
Disclaimers
===========
Any opinions or actions taken by the listed funding institutions are those of
the institutions and do not necessarily reflect the views of the pysatCDAAC
development team or individual authors. Any opinions, findings, and conclusions
or recommendations expressed in this material are those of the author(s) and do
not necessarily reflect the views of the funding agencies.
